@@ -13,8 +13,9 @@ define([
     'vp_base/js/com/com_makeDom',
     'vp_base/js/com/component/SuggestInput',
     'vp_base/js/com/component/VarSelector2',
-    'vp_base/js/com/component/DataSelector'
-], function (com_util, com_makeDom, SuggestInput, VarSelector2, DataSelector) {
+    'vp_base/js/com/component/DataSelector',
+    'vp_base/js/com/component/FileNavigation'
+], function (com_util, com_makeDom, SuggestInput, VarSelector2, DataSelector, FileNavigation) {
     /**
      * show result after code executed
      */
@@ -41,7 +42,9 @@ define([
         'textarea': 'Input textarea',
         'input_number': 'Input number',
         'input_text': 'Input text', 
-        'input': 'Input value'
+        'input': 'Input value',
+        'file_save': 'Select file',
+        'file_load': 'Select file'
     }
 
     const _VP_BOOL_OPTIONS = [
@@ -121,18 +124,20 @@ define([
      * Generate page interface based on package configuration
      * @param {Component} pageThis
      * @param {*} package 
+     * @param {Object} state [optional]
+     * @param {String} parent [optional] parent selector as string
      */
-    var vp_showInterfaceOnPage = function(pageThis, package, state={}) {
+    var vp_showInterfaceOnPage = function(pageThis, package, state={}, parent='') {
 
         // generate input variable tag
-        var tblInput = $(pageThis.wrapSelector()+' #vp_inputOutputBox table tbody');
+        var tblInput = $(pageThis.wrapSelector() + (parent!==''?(' ' + parent):'') + ' #vp_inputOutputBox table tbody');
         // generate option variable tag
-        var tblOption = $(pageThis.wrapSelector()+' #vp_optionBox table tbody');
+        var tblOption = $(pageThis.wrapSelector() + (parent!==''?(' ' + parent):'') + ' #vp_optionBox table tbody');
 
         package.options && package.options.forEach(function(o, i) {
             var obj = JSON.parse(JSON.stringify(o));
             let newTag = vp_createTag(pageThis, obj, state);
-            if (obj.required) {
+            if (obj.required === true || obj.output === true) {
                 tblInput.append(newTag);
             } else {
                 tblOption.append(newTag);
@@ -140,6 +145,9 @@ define([
         });
 
         // TODO: userOption
+        if (package.code.includes('${etc}')) {
+            
+        }
 
         bindAutoComponentEvent(pageThis);
     }
@@ -161,7 +169,7 @@ define([
         let value = state[name];
         
         var requiredFontStyle = required == true? 'vp-orange-text' : '';
-        var lblTag = $(`<label>${label}</label>`).attr({
+        var lblTag = $(`<label class="vp-bold">${label}</label>`).attr({
             'for': name,
             'class': requiredFontStyle,
             'title': '(' + name + ')'
@@ -368,6 +376,7 @@ define([
                     type: 'text',
                     id: obj.name,
                     class: 'vp-input vp-state',
+                    placeholder: obj.placeholder || 'Select data',
                     required: obj.required === true
                 });
                 vp_generateVarSuggestInput(pageThis.wrapSelector(), obj);
@@ -429,10 +438,86 @@ define([
                 }
                 content = input;
                 break;
+            case 'file-save':
+                var input = $('<input/>').attr({
+                    type: 'text',
+                    class: 'vp-input input-single vp-state',
+                    id: obj.name,
+                    placeholder: (obj.placeholder==undefined?'Input Data':obj.placeholder),
+                    value: (obj.default==undefined?'':obj.default),
+                    title: (obj.help==undefined?'':obj.help),
+                    required: obj.required == true
+                });
+                // cell metadata test
+                if (value != undefined) {
+                    // set as saved value
+                    $(input).attr({
+                        'value': value
+                    });
+                }
+                var fileBrowerButton = $(`<div class="vp-file-browser-button" data-parent="${obj.name}"></div>`);
+                var div = $('<div></div>');
+                div.append(input);
+                div.append(fileBrowerButton);
+
+                $(document).off('click', pageThis.wrapSelector(`.vp-file-browser-button[data-parent="${obj.name}"]`));
+                $(document).on('click', pageThis.wrapSelector(`.vp-file-browser-button[data-parent="${obj.name}"]`), function() {
+                    let fileNavi = new FileNavigation({
+                        type: 'save',
+                        extensions: (obj.fileExtension==undefined?[]:[obj.fileExtension]),
+                        finish: function(filesPath, status, error) {
+                            let {file, path} = filesPath[0];
+    
+                            // set text
+                            $(pageThis.wrapSelector('#' + obj.name)).data('file', file);
+                            $(pageThis.wrapSelector('#' + obj.name)).val(path);
+                        }
+                    });
+                    fileNavi.open();
+                });
+                content = div;
+                break;
+            case 'file-open':
+                var input = $('<input/>').attr({
+                    type: 'text',
+                    class: 'vp-input input-single vp-state',
+                    id: obj.name,
+                    placeholder: (obj.placeholder==undefined?'Input Data':obj.placeholder),
+                    value: (obj.default==undefined?'':obj.default),
+                    title: (obj.help==undefined?'':obj.help),
+                    required: obj.required == true
+                });
+                // cell metadata test
+                if (value != undefined) {
+                    // set as saved value
+                    $(input).attr({
+                        'value': value
+                    });
+                }
+                var fileBrowerButton = $(`<div class="vp-file-browser-button" data-parent="${obj.name}"></div>`);
+                var div = $('<div></div>');
+                div.append(input);
+                div.append(fileBrowerButton);
+
+                $(document).off('click', pageThis.wrapSelector(`.vp-file-browser-button[data-parent="${obj.name}"]`));
+                $(document).on('click', pageThis.wrapSelector(`.vp-file-browser-button[data-parent="${obj.name}"]`), function() {
+                    let fileNavi = new FileNavigation({
+                        type: 'open',
+                        extensions: (obj.fileExtension==undefined?[]:[obj.fileExtension]),
+                        finish: function(filesPath, status, error) {
+                            let {file, path} = filesPath[0];
+    
+                            // set text
+                            $(pageThis.wrapSelector('#' + obj.name)).data('file', file);
+                            $(pageThis.wrapSelector('#' + obj.name)).val(path);
+                        }
+                    });
+                    fileNavi.open();
+                });
+                content = div;
+                break;
             case 'table':
                 // break;
-            case 'file':
-                // break;
             // default : input_single
             default:
                 var input = $('<input/>').attr({
@@ -463,7 +548,7 @@ define([
      * @param {object} obj
      */
     var vp_generateVarSuggestInput = function(divTag, obj) {
-        var types = obj.var_type;
+        var types = obj.varType;
         var defaultValue = obj.value;
         if (obj.value == undefined && obj.default != undefined) {
             defaultValue = obj.default;
@@ -572,27 +657,28 @@ define([
 
     /**
      * Get tag value
-     * @param {Object} pageThis
-     * @param {*} obj 
-     * @returns {string} tag's value
+     * @param {Object} pageThis parent this object
+     * @param {Object} obj      state object to get tag value 
+     * @param {string} parent   parent selector as string
+     * @returns {string}        tag's value
      */
-    var vp_getTagValue = function(pageThis, obj) {
+    var vp_getTagValue = function(pageThis, obj, parent='') {
         var value = '';
         let componentType = 'input';
         if (obj.component && obj.component.length == 1) {
             componentType = obj.component[0];
         } else {
-            componentType = $(pageThis.wrapSelector('#' + obj.name + '_type')).val();
+            componentType = $(pageThis.wrapSelector(parent + ' #' + obj.name + '_type')).val();
         }
         switch (componentType) {
             case 'option_radio':
-                var input = $(pageThis.wrapSelector("input[name='"+obj.name+"']:checked")).val();
+                var input = $(pageThis.wrapSelector(parent + " input[name='"+obj.name+"']:checked")).val();
                 // same as default
                 if (input == obj.default) break;
                 value = input;
                 break;
             case 'option_checkbox':
-                let checked = $(pageThis.wrapSelector("input[name='"+obj.name+"']:checked")).val();
+                let checked = $(pageThis.wrapSelector(parent + " input[name='"+obj.name+"']:checked")).val();
 
                 for (var i = 0; i < checked.length; i++) {
                     value += "'" + $(checked[i]).val() + "',";
@@ -600,25 +686,33 @@ define([
                 value = value.substr(0, value.length-1);
                 break;
             case 'bool_checkbox':
-                let isChecked = $(pageThis.wrapSelector('#'+obj.name)).prop('checked');
+                let isChecked = $(pageThis.wrapSelector(parent + ' #'+obj.name)).prop('checked');
                 value = isChecked?'True':'False';
                 break;
+            case 'var_multi':
+                let multiValue = $(pageThis.wrapSelector(parent + ' #'+obj.name)).val();
+                if (multiValue && multiValue.length > 0) {
+                    value = multiValue.join(', ');
+                } else {
+                    value = '';
+                }
+                break;
             case 'input_multi':
             case 'bool_select':
             case 'data_select':
             case 'var_select':
-            case 'var_multi':
             case 'col_select':
             case 'dtype':
-                value = $(pageThis.wrapSelector('#'+obj.name)).val();
+                value = $(pageThis.wrapSelector(parent + ' #'+obj.name)).val();
                 break;
+            case 'file-open':
+            case 'file-save':
             case 'table':
-            case 'file':
             case 'option_select':
             case 'option_suggest':
             case 'input_number':
             default:
-                var input = $(pageThis.wrapSelector('#'+obj.name)).val();
+                var input = $(pageThis.wrapSelector(parent + ' #'+obj.name)).val();
                 // same as default
                 if (input == obj.default) break;
                 value = input;
@@ -630,17 +724,19 @@ define([
      * Generate code
      * @param {Object} pageThis
      * @param {Object} package 
+     * @param {Object} state      [optional]
      * @param {string} etcOptions [optional] userOptionCode addition ex) ", test='TEST'"
+     * @param {string} parent     [optional] parent selector as string
      * @returns {string} generated code / if error, null
      */
-    var vp_codeGenerator = function(pageThis, package, state = {}, etcOptions = '') {
+    var vp_codeGenerator = function(pageThis, package, state = {}, etcOptions = '', parent='') {
         var code = package.code;
         
         try {
             package.options && package.options.forEach(function(v, i) {
                 var val = state[v.name];
                 if (val == undefined || val == '' || val == v.default) {
-                    val = vp_getTagValue(pageThis, v);
+                    val = vp_getTagValue(pageThis, v, parent=parent);
                 }
                 var id = '${' + v.name + '}';
                 if (val == undefined || val.trim() == '') {
@@ -651,7 +747,8 @@ define([
                     code = code.split(id).join('');
                 } else {
                     // text quotation
-                    if (v.type == 'text') {
+                    if (v.type == 'text' 
+                        || (v.component != undefined && (v.component.includes('file-open') || v.component.includes('file-save')))) {
                         val = "'"+val+"'";
                     } 
                     // code completion
@@ -687,7 +784,27 @@ define([
             // prevent code: no allocation variable ( = pd.DataFrame())
             if (code.startsWith(' = ')) {
                 code = code.substr(3);
+            } 
+            // prevent code: without allocation code (${o0} = code)
+            let outputCodeMatch = code.match(/^\$\{.+\} = /);
+            if (outputCodeMatch) {
+                let matchLength = outputCodeMatch[0].length;
+                let matchStartIdx = outputCodeMatch['index'];
+                code = code.substr(matchStartIdx + matchLength);
             }
+            // show_result 
+            // get output variables
+            if (_VP_SHOW_RESULT && package.options) {
+                var outputOptList = package.options.filter(x => x.output === true);
+                var outputStr = '';
+                outputOptList.forEach(opt => {
+                    outputStr += (outputStr !== ''?', ':'') + vp_getTagValue(pageThis, opt);
+                })
+                if (outputStr != '') {
+                    code += '\n'+ outputStr;
+                }
+            }
+
 
         } catch (e) {
             vpLog.display(VP_LOG_TYPE.ERROR, 'com_generator v2 code generation error ' + e.message);
