@@ -3,8 +3,10 @@ define([
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
-    'vp_base/js/com/component/SuggestInput'
-], function(insCss, com_Const, com_String, com_util, SuggestInput) {
+    'vp_base/js/com/component/SuggestInput',
+    'vp_base/data/m_library/instanceLibrary',
+    'vp_base/js/com/component/LibraryComponent'
+], function(insCss, com_Const, com_String, com_util, SuggestInput, instanceLibrary, LibraryComponent) {
 
 
     // temporary const
@@ -35,12 +37,17 @@ define([
      * @constructor
      */
     class InstanceEditor {
-        constructor(pageThis, targetId, containerId = 'vp_wrapper', popup = false) {
+        constructor(pageThis, targetId, containerId = 'vp_wrapper', config = {}) {
             this.pageThis = pageThis;
             this.targetId = targetId;
             this.uuid = 'u' + com_util.getUUID();
             this.containerId = containerId;
-            this.popup = popup;
+            this.config = {
+                popup: false,
+                showAlert: false, // show alert by modal or not
+                targetType: 'instance', // instance / outside
+                ...config
+            }
 
             this.state = {
                 code: '',
@@ -70,7 +77,6 @@ define([
             return this.state.list;
         }
         init() {
-
             this.reload();
         }
         wrapSelector(selector = '') {
@@ -166,6 +172,7 @@ define([
             tag.appendFormatLine('<div class="{0}">', VP_INS_PARAMETER_BOX);
             tag.appendFormatLine('<input type="text" class="{0}" placeholder="{1}"/>',
                 VP_INS_PARAMETER, 'input parameter');
+            tag.appendFormatLine('<button class="vp-button disabled {0}">Option</button>', 'vp-ins-opt-button');
             tag.appendLine('</div>'); // VP_INS_PARAMETER
 
             tag.appendLine('</div>'); // VP_INS_BOX END
@@ -279,6 +286,13 @@ define([
                     }
                 }
             });
+
+            // open option popup
+            $(document).on('click', this.wrapSelector('.vp-ins-opt-button:not(.disabled)'), function(event) {
+                if (that.optionPopup) {
+                    that.optionPopup.open();
+                }
+            });
         }
         reload(callback = undefined) {
             var that = this;
@@ -289,19 +303,98 @@ define([
                 return;
             }
             this.state.code = variable;
+            var prevVarType = that.state.type;
 
             if (variable == '') {
                 if (!this.isFirstPage) {
-                    this.renderFirstPage();
-                    this.isFirstPage = true;
+                    // if it's outside mode
+                    if (this.config.targetType === 'outside') {
+                        this.isFirstPage = false;
+                        this.renderPage();
+                        return;
+                    } else {
+                        this.renderFirstPage();
+                        this.isFirstPage = true;
+                    }
                 }
             } else {
                 this.isFirstPage = false;
                 this.renderPage();
             }
+            var splitList = [];
+            if (variable != '') {
+                splitList = variable.split('.');
+            }
+            var hasOption = false;
+            // get parameter
+            if (splitList && splitList.length > 0) {
+                var lastSplit = splitList[splitList.length - 1];
+                // get target code
+                var methodName = lastSplit.match(/[a-zA-Z_]+/i)[0];
+                var targetCode = splitList.slice(0, splitList.length - 1).join('.');
+                if ((prevVarType in instanceLibrary.INSTANCE_MATCHING_LIBRARY) && (methodName in instanceLibrary.INSTANCE_MATCHING_LIBRARY[prevVarType])) {
+                    // get target library
+                    var targetLib = instanceLibrary.INSTANCE_MATCHING_LIBRARY[prevVarType][methodName];
+                    var targetId = targetLib.target;
+                    var popupState = {
+                        config: { 
+                            name: methodName, category: 'Instance',
+                            id: targetLib.id,
+                            saveOnly: true,
+                            noOutput: true
+                        }
+                    }
+                    // add targetid as state if exists
+                    if (targetId) {
+                        popupState[targetId] = targetCode;
+                    }
+                    that.optionPopup = new LibraryComponent(popupState,
+                        { 
+                            pageThis: that,
+                            useInputVariable: true,
+                            targetSelector: that.pageThis.wrapSelector('#' + that.targetId),
+
+                            finish: function(code) {
+                                // set parameter
+                                let lastSplit = code?.split('.')?.pop();
+                                // if bracket is at the end of code
+                                let matchList = lastSplit.match(/\(.*?\)$/gi);
+                                if (matchList != null && matchList.length > 0) {
+                                    let lastBracket = matchList[matchList.length - 1];
+                                    // remove first/last brackets
+                                    let parameter = lastBracket.substr(1, lastBracket.length - 2);
+                                    $(that.wrapSelector('.' + VP_INS_PARAMETER)).val(parameter);
+                                }
+
+                                $(that.pageThis.wrapSelector('#' + that.targetId)).trigger({
+                                    type: "instance_editor_replaced",
+                                    originCode: that.state.code,
+                                    newCode: code
+                                });
+                            }
+                        }
+                    );
+                    hasOption = true;
+                } else {
+                    that.optionPopup = null;
+                }
+
+                if (hasOption) {
+                    if ($(that.wrapSelector('.vp-ins-opt-button')).hasClass('disabled')) {
+                        $(that.wrapSelector('.vp-ins-opt-button')).removeClass('disabled');
+                    }
+                } else {
+                    if (!$(that.wrapSelector('.vp-ins-opt-button')).hasClass('disabled')) {
+                        $(that.wrapSelector('.vp-ins-opt-button')).addClass('disabled');
+                    }
+                }
+            } else {
+                if (!$(that.wrapSelector('.vp-ins-opt-button')).hasClass('disabled')) {
+                    $(that.wrapSelector('.vp-ins-opt-button')).addClass('disabled');
+                }
+            }
 
             var code = com_util.formatString('_vp_print(_vp_load_instance("{0}"))', variable);
-
             vpKernel.execute(code).then(function (resultObj) {
                 let { result } = resultObj;
                 var varObj = {
@@ -316,6 +409,10 @@ define([
 
                 var varType = varObj.type;
                 var varList = varObj.list;
+                if (varType == 'module') {
+                    // get module name
+                    varType = varObj.name;
+                }
 
                 that.state.type = varType;
                 that.state.list = varList;
@@ -407,9 +504,9 @@ define([
                     });
 
                     // get parameter
-                    var splitList = variable.split('.');
                     if (splitList && splitList.length > 0) {
                         var lastSplit = splitList[splitList.length - 1];
+                        
                         // if bracket is at the end of code
                         var matchList = lastSplit.match(/\(.*?\)$/gi);
                         if (matchList != null && matchList.length > 0) {
@@ -417,26 +514,22 @@ define([
                             // remove first/last brackets
                             var parameter = lastBracket.substr(1, lastBracket.length - 2);
                             $(that.wrapSelector('.' + VP_INS_PARAMETER)).val(parameter);
-                            $(that.wrapSelector('.' + VP_INS_PARAMETER)).show();
+                            $(that.wrapSelector('.' + VP_INS_PARAMETER)).prop('disabled', false);
                         } else {
                             $(that.wrapSelector('.' + VP_INS_PARAMETER)).val('');
-                            $(that.wrapSelector('.' + VP_INS_PARAMETER)).hide();
+                            $(that.wrapSelector('.' + VP_INS_PARAMETER)).prop('disabled', true);
                         }
                     } else {
-                        $(that.wrapSelector('.' + VP_INS_PARAMETER)).hide();
+                        $(that.wrapSelector('.' + VP_INS_PARAMETER)).prop('disabled', true);
                     }
                 }
-
-                // callback
-                if (callback) {
-                    callback(varObj);
-                }
             }).catch(function(resultObj) {
                 let { result } = resultObj;
                 // show alert if this is visible
-                if (that.pageThis.isHidden() == false) {
+                if (that.pageThis.isHidden() == false && that.config.showAlert == true) {
                     com_util.renderAlertModal(result.ename + ': ' + result.evalue);
                 }
+            }).finally(function() {
                 // callback
                 if (callback) {
                     callback('');
