@@ -9,6 +9,24 @@
  *    Change Date     :
  */
 
+/** DEPRECATED on v2.3.5
+ * - libraries.json
+    {
+        "id"   : "apps_profiling",
+        "type" : "function",
+        "level": 1,
+        "name" : "Profiling",
+        "tag"  : "PROFILING,PANDAS PROFILING,APPS",
+        "path" : "visualpython - apps - profiling",
+        "desc" : "Pandas Profiling",
+        "file" : "m_apps/Profiling",
+        "apps" : {
+            "color": 4,
+            "icon": "apps/apps_profiling.svg"
+        }
+    }
+ */
+
 //============================================================================
 // [CLASS] Profiling
 //============================================================================
